Module runner

Module runner 

Core execution functions for running OpenScript code.

Functions

run
Run an OpenScript from a string and wait for completion.
run_file
Run an OpenScript file and wait for completion.
spawn
Spawn an OpenScript process from a string without waiting for completion.
spawn_file
Spawn an OpenScript process from a file without waiting for completion.