pub struct SpawnResult {
pub child: Child,
/* private fields */
}Expand description
Result of a spawn operation.
This struct holds the Child process handle and ensures that any temporary
files created for the script live as long as the handle.
Fields
child: ChildTrait Implementations