Core execution functions for running OpenScript code.
Functions
- run
- Run an OpenScript from a string and wait for completion.
- run_
file - Run an OpenScript file and wait for completion.
- spawn
- Spawn an OpenScript process from a string without waiting for completion.
- spawn_
file - Spawn an OpenScript process from a file without waiting for completion.